#ifndef QUEUE_H
#define QUEUE_H
 
typedef void *qelem_t;
 
typedef struct qnode
{
        qelem_t elem;
        struct qnode *next;
        struct qnode *prev;
}qnode;
 
typedef struct
{
		int count;
		int status;
        qnode *back;
        qnode *front;
}queue;
 
/*
 * Create a queue.
 */
queue *q_create(void);
 
/*
 * Destroy a queue.
 * Returns 1 on success, and otherwise 0.
 */
int q_destroy(queue *q);
 
/*
 * Check if queue is empty.
 * Returns 1 if the queue is empty, 2 if the queue is not created, 0 if not empty.
 */
int q_isempty(queue *q);
 
 /*
 * Check if queue is full.
 * Returns 1 if the queue is not full, 0 if the queue is full.
 */
int q_isfull(queue *q); 
/*
 * Add element to queue.
 * Returns 1 on success, and otherwise 0.
 */
int q_enqueue(queue *q, qelem_t elem);
 
/*
 * Delete element from the queue.
 * Returns element from queue on success, and otherwise NULL.
 */
qelem_t q_dequeue(queue *q);
/*
 * Counts queue size.
 * Returns queue size on success, and 0 if the queue is not created.
 */
int q_size(queue *q);
/*
 * Returns front element from the queue.
 * Returns front element on success, and otherwise NULL.
 */
qelem_t q_front(queue *q);
 

#endif